﻿using CommandLine;
using CommandLine.Text;

namespace PhotoRenamer
{
    /// <summary>
    /// Class to parse and hold the command line options.
    /// </summary>
    class Options
    {
        /// <summary>
        /// Location of the source files.
        /// </summary>
        [Option('d', "directory", DefaultValue = ".", HelpText = "Directory containing files to be renamed (default = .)")]
        public string SourceDirectory { get; set; }

        /// <summary>
        /// Extension for raw image files.
        /// </summary>
        /// <remarks>
        /// This is defaulted to NEF for the Nikon raw files.
        /// </remarks>
        [Option('r', "raw", DefaultValue = "nef", HelpText = "File extension for the raw image files (default = NEF)")]
        public string RawExtension { get; set; }

        /// <summary>
        /// File extension for the processed image files.
        /// </summary>
        [Option('j', "jpeg", DefaultValue = "jpg", HelpText = "File extension for the image files (default = JPG)")]
        public string JPGExtension { get; set; }

        /// <summary>
        /// Is the application in verbose mode?
        /// </summary>
        [Option('v', "verbose", DefaultValue = false, HelpText = "Prints all messages to standard output.")]
        public bool Verbose { get; set; }

        /// <summary>
        /// New source name for the files.
        /// </summary>
        [Option('n', "name", Required = true, HelpText = "Root of the new file name.")]
        public string Name { get; set; }

        [ParserState]
        public IParserState LastParserState { get; set; }

        /// <summary>
        /// Build up the usage text.
        /// </summary>
        /// <returns>Options string</returns>
        [HelpOption]
        public string GetUsage()
        {
            return HelpText.AutoBuild(this, (HelpText current) => HelpText.DefaultParsingErrorsHandler(this, current));
        }
    }
}
